@@ -24,10 +24,18 @@
 #define PYSIDE_METAFUNCTION_P_H
 
 #include <sbkpython.h>
+#include <QList>
+#include <QByteArray>
+
+class QObject;
 
 namespace PySide { namespace MetaFunction {
 
-    void            init(PyObject* module);
+    void init(PyObject* module);
+    /**
+     * Does a Qt metacall on a QObject
+     */
+    bool call(QObject* self, int methodIndex, PyObject* args, PyObject** retVal = 0);
 
 } //namespace MetaFunction
 } //namespace PySide
