@@ -24,7 +24,7 @@
 #define SIGNALMANAGER_H
 
 #include "pysidemacros.h"
-#include <Python.h>
+#include <sbkpython.h>
 #include <Qt>
 #include <QStringList>
 #include <QMetaMethod>
@@ -79,6 +79,8 @@ public:
     // Disconnect all signals managed by Globalreceiver
     void clear();
 
+    // Utility function to call a python method usign args received in qt_metacall
+    static int callPythonMetaMethod(const QMetaMethod& method, void** args, PyObject* obj, bool isShortCuit);
 
     PYSIDE_DEPRECATED(QObject* globalReceiver());
     PYSIDE_DEPRECATED(void addGlobalSlot(const char* slot, PyObject* callback));
